#
# spec file for package python-efl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}

%if 0%{?suse_version} > 1599
%define build_doc 1
%else
%define build_doc 0
%endif

Name:           python-efl
Version:        1.26.1
Release:        1.3
Summary:        Python bindings of evas
License:        GPL-3.0-only AND LGPL-3.0-only
Group:          Development/Libraries/Python
URL:            http://enlightenment.org
Source:         https://download.enlightenment.org/rel/bindings/python/%{name}-%{version}.tar.xz
Patch0:         cython3.patch
%if 0%{?suse_version} > 1599
BuildRequires:  %{python_module Cython3}
%else
BuildRequires:  %{python_module Cython}
%endif
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dbus-1-python3-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ecore)
BuildRequires:  pkgconfig(edje)
BuildRequires:  pkgconfig(elementary)
BuildRequires:  pkgconfig(emotion)
BuildRequires:  pkgconfig(eo)
BuildRequires:  pkgconfig(evas)
# cc1 uses too much memory on x86
#ExcludeArch:    %ix86
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# pre-unification mess
%if "%{python_flavor}" == "python2"
Obsoletes:      python-evas < %{version}
Provides:       python-evas = %{version}
Obsoletes:      python-ecore < %{version}
Provides:       python-ecore = %{version}
Obsoletes:      python-edje < %{version}
Provides:       python-edje = %{version}
Obsoletes:      python-emotion < %{version}
Provides:       python-emotion = %{version}
Obsoletes:      python-e_dbus < %{version}
Provides:       python-e_dbus = %{version}
Obsoletes:      python-elementary < %{version}
Provides:       python-elementary = %{version}
%endif
%endif

%if 0%{?suse_version}
%python_subpackages
%else

%package -n python3-efl
Summary:        Python bindings of evas
Group:          Development/Languages/Python

%description -n python3-efl
Python bindings of the Enlightenment Foundation Libraries (efl).
%endif

%description
Python bindings of the Enlightenment Foundation Libraries (efl).

%if 0%{?suse_version}
%if %{build_doc}
%package -n python-efl-doc
Summary:        Documentation for python-efl
Group:          Documentation/HTML
BuildRequires:  %{python_module Sphinx}
Provides:       python3-efl-doc
Conflicts:      otherproviders(python3-efl-doc)

%description -n python-efl-doc
HTML formated documentation for python-efl module.
%endif

%package -n python-efl-examples
Summary:        Examples of python-efl usage
Group:          Documentation/Other
Provides:       python3-efl-examples
Conflicts:      otherproviders(python3-efl-examples)

%description -n python-efl-examples
Some examples of usage of python-efl.
%endif

%prep
%setup -q
%if 0%{?suse_version} > 1599
%patch -P 0 -p1
%endif
# drop build date from doc to fix build-compare
sed -i "s/\(html_last_updated_fmt = \).*/\\1None/" ./doc/conf.py

%build
export ENABLE_CYTHON=1
export CFLAGS="$CFLAGS -Wno-declaration-after-statement"
%ifarch %ix86
export CFLAGS="$CFLAGS -O0"
%endif
%if 0%{?suse_version}
%{python_expand $python setup.py build -g}
%if %{build_doc}
python3 -m sphinx.cmd.build doc build/sphinx/html
%endif
%else
%py2_build
%py3_build
%endif

%install
export DISABLE_CYTHON=1

# module itself
%{?suse_version:%python_install}
%{!?suse_version:%py2_install}
%{!?suse_version:%py3_install}

# documentation
%if 0%{?suse_version}
%if %{build_doc}
for _name in python-efl python3-efl; do
  install -m 0755 -d "%{buildroot}/%{_docdir}/$_name"
  cp -R build/sphinx/html "%{buildroot}/%{_docdir}/$_name"
  rm -r "%{buildroot}/%{_docdir}/$_name"/html/.{buildinfo,doctrees}
done

%python_expand %fdupes %{buildroot}%{_docdir}
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

# examples
for _name in python-efl python3-efl; do
  install -m 0755 -d "%{buildroot}/%{_datadir}/$_name"
  cp -R examples/  "%{buildroot}/%{_datadir}/$_name/"
  mkdir -p %{buildroot}/%{_docdir}/$_name
done
# Remove examples installed under python-efl namespace
rm -r "%{buildroot}/%{_datadir}/%{name}/examples"
rm -r "%{buildroot}/%{_docdir}/%{name}/"
%endif

%if 0%{?suse_version}
%files %{python_files}
%{python_sitearch}/*
%exclude %{_docdir}/python3-efl/html/

%if %{build_doc}
%files -n python-efl-doc
%{_docdir}/python3-efl
%endif

%files -n python-efl-examples
%{_datadir}/python3-efl
%endif

%if !0%{?suse_version}
%files -n python-efl
%license AUTHORS COPYING*
%{python_sitearch}/*

%files -n python3-efl
%license AUTHORS COPYING*
%{python3_sitearch}/*
%endif

%changelog
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.26.1:
  * rebuilt using Cython 0.29.34 to fix install on python 3.11
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Jan 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Unconditionally BuildRequire setuptools: the build relies on it.
* Sat Dec  2 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Remove Sphinx .doctrees for reproducible builds
* Fri Sep  1 2023 Simon Lees <sflees@suse.de>
- Fix Leap build by tweeking dependencies and disabling docs as
  they require newer tooling then Leap provides.
* Thu Aug 31 2023 Fridrich Strba <fstrba@suse.com>
- Use Cython to regenerate files during the build
- Build documentation using sphinx-build since Sphinx 7+ dropped
  the integration with setuptools
- Added patch:
  * cython3.patch
    + Explicite declaration of functions as noexcept:
    in Cython 3+, default swallowing of Python exception is
    deprecated and the new default is to propagate them.
    Generation of files is ending up in error on exception
    mismatch
* Tue Mar 21 2023 Simon Lees <sflees@suse.de>
- Update to 1.26.0
  * Sync with latest efl
- Drop memory-allocation-error.patch fixed upstream
* Mon Jan 10 2022 Andreas Schwab <schwab@suse.de>
- memory-allocation-error.patch: fix a memory allocation error
* Wed Feb 24 2021 Simon Lees <sflees@suse.de>
- Fix conflicts and provides for docs packages
* Wed Feb 10 2021 Simon Lees <sflees@suse.de>
- Only create docs and examples packages once
* Sun Nov  8 2020 Simon Lees <sflees@suse.de>
- Update to 1.25.0
  * Sync with the latest efl release
* Thu Jun 25 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix _constraints
* Fri Jun 12 2020 Simon Lees <sflees@suse.de>
- Disable python2, broken on Leap and nothing uses it
* Tue May 26 2020 Simon Lees <sflees@suse.de>
- Fix issues with docs conflicts
* Tue May  5 2020 Simon Lees <sflees@suse.de>
- Update to 1.24.0
  * As always new features of EFL have been ported and the usual
    has been done in fixing bugs, optimizing speed and improve
    documentation.  (see **ChangeLog** in the tarball for the
    full list of changes)
* Thu Apr 23 2020 Simon Lees <sflees@suse.de>
- Explicitly require python3-Sphinx due to the module way being
  now unresolvable.
* Fri Nov  8 2019 Simon Lees <sflees@suse.de>
- Update to 1.23.0 in line with efl
* Sun Jul  7 2019 Jan Engelhardt <jengelh@inai.de>
- Fix a Group: line.
- In descriptions, EFL needs to be camel cased because it is a
  proper noun (a name).
* Thu May  2 2019 Simon Lees <sflees@suse.de>
- Update to 1.22.0 with efl
* Thu Feb  7 2019 Simon Lees <sflees@suse.de>
- Update to 1.21.0 in line with efl
* Wed Oct  4 2017 avvissu@yandex.by
- Build with Python2 on Fedora and Mageia
- Build on ix86 (add the -O0 optimization to flags)
- Fix build on Fedora and Mageia
- Use a single spec file (build with Python2 and Python3)
- Spec file cleanup
* Tue Sep  5 2017 sflees@suse.de
- i586 builds are working again, reenable them
- update the efl version requirement to be correct
* Wed Aug 23 2017 sflees@suse.de
- Sync with efl 1.20
* Tue Jun 27 2017 lnussel@suse.de
- Exclude x86, cc1 uses too much memory atm
* Thu Jun 22 2017 sflees@suse.de
- Add a _constraints file to fix out of mem issues
* Wed May 17 2017 sflees@suse.de
- Update to 1.19.0
  * changes in line with 1.19.X changes in efl
* Wed Aug 31 2016 sflees@suse.de
- Another attempt at python3 - Removes python2 support
* Sat Nov 14 2015 simon@simotek.net
- 1.16.0 pre release will add full changes with release
* Fri Aug 21 2015 simon@simotek.net
- Add COPYING.* AUTHORS to package
* Sat Aug 15 2015 simon@simotek.net
- Bindings update to efl 1.15.x
  Fixes:
    elm.Entry: Fixed name of the callback_rejected_del function
    Fixed build on OSX
    Fixed build when ecore-x is not available
    Fixed module init from embedded interpreter
  Changes:
    Elm: Unify modules into a monolithic module
  Additions:
    elm.Configuration.transition_duration_factor
    elm.Window.autohide
    elm.ELM_POLICY_QUIT_LAST_WINDOW_HIDDEN
    elm.Entry.callback_context_open_add/del
    elm.ELM_FOCUS_MOVE_POLICY_KEY_ONLY
    elm.Object.focus_move_policy
    elm.Scrollable.wheel_disabled
    evas.Textblock.obstacle_add
    evas.Textblock.obstacle_del
    evas.Textblock.obstacles_update
    evas.EVAS_CALLBACK_CANVA_VIEWPORT_RESIZE
* Thu May  7 2015 simon@simotek.net
- Bindings updated to efl 1.14.X
* Mon Feb 16 2015 simon@simotek.net
- Bindings updated to match efl 1.13.x
* Fri Jan  9 2015 simon@simotek.net
- Bindings updated to match efl 1.12.x
* Tue Sep 16 2014 simon@simotek.net
- bump to 1.11.0
  * * Re enabled cython building **
  No new features upstream just following efl changes
* Mon Aug 18 2014 simon@simotek.net
- Disabled Cython with env var for this release as the upstream tar was broken.
  It was missing .pxd files this has been fixed for the next release.
* Sun Jun  1 2014 sleep_walker@suse.cz
- bump to 1.10.0 (but missing any short changelog)
- correct all provides and obsoletes
* Wed Apr  9 2014 simon@simotek.net
- version 1.9.0
  Release Notes:
  No major changes have been made since the last 1.8 release. All the new
  features of efl and elementary 1.9 has been ported and the usual has been
  done in fixing bugs and optimizing speed. (see **changes.html** in the
  tarball for the full list of changes)
* Tue Dec 17 2013 sleep_walker@suse.cz
- change to use pkgconfig dependencies
- beutify spec a bit
* Mon Dec  9 2013 sleep_walker@suse.cz
- let there by python-efl!
